pytilities.types.sequencetype.SequenceType

Package pytilities :: Package types :: Module sequencetype :: Class SequenceType |
[hide private]
[frames] | no frames]

# Class SequenceType

source code

    object --+
             |
            SequenceType

Represents any ordered sequence.

A sequence supports indexed access (i.e., [] access, __getitem__, ...).

Lists and tuples are subtypes of this type.

Nested Classes | [hide private]
| __metaclass__

Instance Methods | [hide private]
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__init__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`